@@ -28,6 +28,8 @@ Helper methods to deal with images.
 import json
 import re
 
+import debtcollector
+
 from oslo_utils._i18n import _
 from oslo_utils import strutils
 
@@ -38,8 +40,11 @@ class QemuImgInfo(object):
     The instance of :class:`QemuImgInfo` has properties: `image`,
     `backing_file`, `file_format`, `virtual_size`, `cluster_size`,
     `disk_size`, `snapshots` and `encrypted`.
+
     The parameter format can be set to 'json' or 'human'. With 'json' format
     output, qemu image information will be parsed more easily and readable.
+    However 'human' format support will be dropped in next cycle and only
+    'json' format will be supported. Prefer to use 'json' instead of 'human'.
     """
     BACKING_FILE_RE = re.compile((r"^(.*?)\s*\(actual\s+path\s*:"
                                   r"\s+(.*?)\)\s*$"), re.I)
@@ -53,17 +58,25 @@ class QemuImgInfo(object):
             details = json.loads(cmd_output or '{}')
             self.image = details.get('filename')
             self.backing_file = details.get('backing-filename')
+            self.backing_file_format = details.get('backing-filename-format')
             self.file_format = details.get('format')
             self.virtual_size = details.get('virtual-size')
             self.cluster_size = details.get('cluster-size')
             self.disk_size = details.get('actual-size')
             self.snapshots = details.get('snapshots', [])
-            self.encrypted = details.get('encrypted')
+            self.encrypted = 'yes' if details.get('encrypted') else None
             self.format_specific = details.get('format-specific')
         else:
+            if cmd_output is not None:
+                debtcollector.deprecate(
+                    'The human format is deprecated and the format parameter '
+                    'will be removed. Use explicitly json instead',
+                    version="xena",
+                    category=FutureWarning)
             details = self._parse(cmd_output or '')
             self.image = details.get('image')
             self.backing_file = details.get('backing_file')
+            self.backing_file_format = details.get('backing_file_format')
             self.file_format = details.get('file_format')
             self.virtual_size = details.get('virtual_size')
             self.cluster_size = details.get('cluster_size')
@@ -80,6 +93,7 @@ class QemuImgInfo(object):
             'disk_size: %s' % self.disk_size,
             'cluster_size: %s' % self.cluster_size,
             'backing_file: %s' % self.backing_file,
+            'backing_file_format: %s' % self.backing_file_format,
         ]
         if self.snapshots:
             lines.append("snapshots: %s" % self.snapshots)
