@@ -23,8 +23,6 @@ import re
 import unicodedata
 import urllib
 
-import pyparsing as pp
-
 from oslo_utils._i18n import _
 from oslo_utils import encodeutils
 
@@ -303,8 +301,6 @@ def mask_password(message, secret="***"):  # nosec
     '"password" : "***"'
     >>> mask_password("'original_password' : 'aaaaa'")
     "'original_password' : '***'"
-    >>> mask_password("u'original_password' :   u'aaaaa'")
-    "u'original_password' :   u'***'"
 
     .. versionadded:: 0.2
 
@@ -577,8 +573,13 @@ def split_by_commas(value):
 
     .. versionadded:: 3.17
     """
-    word = (pp.QuotedString(quoteChar='"', escChar='\\') |
-            pp.Word(pp.printables, excludeChars='",'))
+    # pyparsing is a slow import; defer loading until we need it
+    import pyparsing as pp
+
+    word = (
+        pp.QuotedString(quoteChar='"', escChar='\\') |
+        pp.Word(pp.printables, excludeChars='",')
+    )
     grammar = pp.stringStart + pp.delimitedList(word) + pp.stringEnd
 
     try:
